[dev-python/python-report] version bump, required by new anaconda

This commit is contained in:
Fabio Erculiani
2014-04-27 18:42:41 +01:00
parent eeb0bcf460
commit e2abfe373e
4 changed files with 131 additions and 0 deletions
@@ -0,0 +1,9 @@
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
AC_INIT([report], [0.23])
-AM_INIT_AUTOMAKE([-Wall -Werror foreign])
+AM_INIT_AUTOMAKE([-Wall foreign])
AC_PROG_CC
AC_PROG_CXX
AC_PROG_LIBTOOL
@@ -0,0 +1,19 @@
--- a/python/report/plugins/bugzilla/__init__.py
+++ b/python/report/plugins/bugzilla/__init__.py
@@ -115,8 +115,6 @@ import filer
def sendToBugzilla(component, signature, io, bzfiler,
optionsDict, fileName, fileDescription):
- import rpmUtils.arch
-
class BugzillaCommunicationException (Exception):
pass
@@ -298,7 +296,6 @@ def sendToBugzilla(component, signature,
product=bzfiler.getproduct(),
component=component,
version=bzfiler.getversion(),
- platform=rpmUtils.arch.getBaseArch(),
bug_severity="medium",
priority="medium",
op_sys="Linux",
@@ -0,0 +1,55 @@
--- a/etc/Makefile.am
+++ b/etc/Makefile.am
@@ -1,11 +1,9 @@
nobase_dist_sysconf_DATA = \
-report.d/bugzilla.redhat.com.conf \
-report.d/RHEL-bugzilla.redhat.com.conf \
+report.d/bugs.sabayon.org.conf \
report.conf \
report.d/ftp.conf \
report.d/scp.conf \
report.d/localsave.conf \
-report.d/strata-test.conf \
-report.d/RHEL.conf
+report.d/strata-test.conf
dist_man_MANS = report.conf.5
--- a/etc/report.d/bugs.sabayon.org.conf
+++ b/etc/report.d/bugs.sabayon.org.conf
@@ -0,0 +1,7 @@
+[bugs.sabayon.org]
+# plugin
+plugin=bugzilla
+
+# rhbz url
+bugzilla_host=bugs.sabayon.org
+
--- a/python/report/plugins/bugzilla/__init__.py
+++ b/python/report/plugins/bugzilla/__init__.py
@@ -1,5 +1,5 @@
"""
A Report plugin to send a report to bugzilla.redhat.com.
Copyright (C) 2009 Red Hat, Inc
Author(s): Gavin Romig-Koch <gavin@redhat.com>
@@ -54,7 +54,7 @@ def displayURL(optionsDict):
def bugURL(optionsDict):
if 'bugURL' in optionsDict:
return optionsDict["bugURL"]
- host = "bugzilla.redhat.com"
+ host = "bugs.sabayon.org"
if 'bugzilla_host' in optionsDict:
host = optionsDict["bugzilla_host"]
return "https://" + host + "/xmlrpc.cgi"
@@ -149,8 +149,8 @@ def sendToBugzilla(component, signature,
else:
version = filer.getVersion()
- bzfiler = filer.BugzillaFiler("https://bugzilla.redhat.com/xmlrpc.cgi",
- "http://bugzilla.redhat.com",
+ bzfiler = filer.BugzillaFiler("https://bugs.sabayon.org/xmlrpc.cgi",
+ "http://bugs.sabayon.org",
version, product)
if not bzfiler or not bzfiler.supportsFiling() or not bzfiler.bugUrl:
@@ -1,5 +1,5 @@
"""
- A Report plugin to send a report to bugzilla.redhat.com.
+ A Report plugin to send a report to bugs.sabayon.org.
Copyright (C) 2009 Red Hat, Inc
Author(s): Gavin Romig-Koch <gavin@redhat.com>